ks_test_stat: Internal KScorrect Function.

View source: R/ks_test_stat.R

ks_test_statR Documentation

Internal KScorrect Function.

Description

Internal function not intended to be called directly by users.

Usage

ks_test_stat(x, y, ...)

Arguments

x

a numeric vector of data values.

y

a character string naming a cumulative distribution function or an actual cumulative distribution function such as pnorm. Only continuous CDFs are valid. See LcKS for accepted functions.

...

parameters of the distribution specified (as a character string) by y.

Details

Simplified and faster ks.test function that calculates just the test statistic D for the two-sided null hypothesis.

Note

Calculating the Kolmogorov-Smirnov test statistic D by itself is faster than calculating the other output that that function produces. This function only tests the two-sided null hypothesis.

See Also

ks.test


KScorrect documentation built on July 23, 2026, 5:07 p.m.