Learn R Programming

KScorrect (version 1.4.2)

ks_test_stat: Internal KScorrect Function.

Description

Internal function not intended to be called directly by users.

Usage

ks_test_stat(x, y, ...)

Arguments

x

a numeric vector of data values.

y

a character string naming a cumulative distribution function or an actual cumulative distribution function such as pnorm. Only continuous CDFs are valid. See LcKS for accepted functions.

...

parameters of the distribution specified (as a character string) by y.

Details

Simplified and faster ks.test function that calculates just the test statistic D for the two-sided null hypothesis.

See Also