Internal function not intended to be called directly by users.
ks_test_stat(x, y, ...)a numeric vector of data values.
a character string naming a cumulative distribution function or an
actual cumulative distribution function such as pnorm. Only continuous CDFs
are valid. See LcKS for accepted functions.
parameters of the distribution specified (as a character string) by y.
Simplified and faster ks.test function that calculates
just the test statistic D for the two-sided null hypothesis.